{#<h3>МИНСК 300476/<span style="color: red">!НОМЕР!</span>  {{ date|date:"d/m" }}=</h3>#}
{#<span> </span>#}
{#<h3>Схема двести три =</h3>#}
{#<span> </span>#}
<h3>{{ feed.title }} </h3>
<span> </span>
<h3 style="color: #{{ feed.hazard_level.color_code }}">{{ feed.hazard_level.title }} опасности.</h3>
<span> </span>
<h3>{{ feed.summary }}</h3>





