# Generated by Django 3.0.2 on 2020-01-26 21:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('hazard_feed', '0002_hazardlevels_color_code'),
    ]

    operations = [
        migrations.CreateModel(
            name='WeatherRecipients',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('email', models.EmailField(max_length=254)),
                ('title', models.CharField(max_length=64, null=True)),
                ('is_active', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name': 'Weather hazard recipient',
                'verbose_name_plural': 'Weather hazard recipients',
            },
        ),
    ]
