# Generated by Django 3.0.2 on 2020-01-23 00:15

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='HazardLevels',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=32)),
                ('danger_level', models.IntegerField(validators=[django.core.validators.MaxValueValidator(10)])),
                ('description', models.TextField()),
            ],
            options={
                'verbose_name': 'Hazard Level',
                'verbose_name_plural': 'Hazard Levels',
            },
        ),
        migrations.CreateModel(
            name='HazardFeeds',
            fields=[
                ('id', models.BigIntegerField(primary_key=True, serialize=False)),
                ('date', models.DateTimeField()),
                ('title', models.CharField(max_length=128)),
                ('link', models.URLField()),
                ('summary', models.TextField()),
                ('date_modified', models.DateTimeField()),
                ('hazard_level', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='hazard_feed.HazardLevels')),
            ],
            options={
                'verbose_name': 'Hazard Feed',
                'verbose_name_plural': 'Hazard Feeds',
            },
        ),
    ]
